/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03401
 |         SUBSTANCE ABUSE TREATMENT COST ALLOCATION AND ANALYSIS
 |                  TEMPLATE (SATCAAT) STUDY, 1992-1994
 |       (DATASET 0001: RESIDENTIAL WOMEN AND CHILDREN SDU SUMMARY)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03401-0001-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Substance Abuse Treatment Cost Allocation and Analysis Template (SATCAAT) Study, 1992-1994, Dataset 0001"

#delimit ;
label define CASEID    -9 "BLANK" ;
label define SDUNUM    -9 "BLANK" ;
label define SDUTYPE   -9 "BLANK"
                       1 "RES. PREGNANT & POSTPARTUM WOMEN-SDU SUMMARY"
                       2 "RES. LONG TERM PPW-SDU SUMMARY"
                       3 "RES. SHORT TERM PPW-SDU SUMMARY"
                       4 "RES. WOMEN & CHILDREN-SDU SUMMARY" ;
label define PROVIDER  -9 "BLANK" ;
label define NUMCLNT   -9 "BLANK" ;
label define FYEND     -9 "BLANK" ;
label define TOTCOST   -9 "BLANK" ;
label define TOTAFT    -9 "BLANK" ;
label define TOTCNET   -9 "BLANK" ;
label define TOTCH     -9 "BLANK" ;
label define TOTCLED   -9 "BLANK" ;
label define TOTTRAN   -9 "BLANK" ;
label define TOTHIV    -9 "BLANK" ;
label define TOTHOUS   -9 "BLANK" ;
label define TOTHM     -9 "BLANK" ;
label define TOTIASS   -9 "BLANK" ;
label define TOTMDS    -9 "BLANK" ;
label define TOTMES    -9 "BLANK" ;
label define TOTMHGC   -9 "BLANK" ;
label define TOTMHIC   -9 "BLANK" ;
label define TOTPEVL   -9 "BLANK" ;
label define TOTPSE    -9 "BLANK" ;
label define TOTRMGT   -9 "BLANK" ;
label define TOTSTED   -9 "BLANK" ;
label define TOTSAGC   -9 "BLANK" ;
label define TOTSAIC   -9 "BLANK" ;
label define CSTPRCL   -9.00 "BLANK" ;
label define AVGAFT    -9.00 "BLANK" ;
label define AVGCNET   -9.00 "BLANK" ;
label define AVGCH     -9.00 "BLANK" ;
label define AVGCLED   -9.00 "BLANK" ;
label define AVGTRAN   -9.00 "BLANK" ;
label define AVGHIV    -9.00 "BLANK" ;
label define AVGHOUS   -9.00 "BLANK" ;
label define AVGHM     -9.00 "BLANK" ;
label define AVGIASS   -9.00 "BLANK" ;
label define AVGMDS    -9.00 "BLANK" ;
label define AVGMES    -9.00 "BLANK" ;
label define AVGMHGC   -9.00 "BLANK" ;
label define AVGMHIC   -9.00 "BLANK" ;
label define AVGPEVL   -9.00 "BLANK" ;
label define AVGPSE    -9.00 "BLANK" ;
label define AVGRMGT   -9.00 "BLANK" ;
label define AVGSAGC   -9.00 "BLANK" ;
label define AVGSAIC   -9.00 "BLANK" ;
label define AVGSTED   -9.00 "BLANK" ;
label define UNAFT7    -9 "BLANK" ;
label define UNAFT9    -9 "BLANK" ;
label define UNAFT10   -9 "BLANK" ;
label define UNAFT12   -9 "BLANK" ;
label define UNAFT3    -9 "BLANK" ;
label define UNCNET7   -9 "BLANK" ;
label define UNCNET9   -9 "BLANK" ;
label define UNCNET10  -9 "BLANK" ;
label define UNCNET16  -9 "BLANK" ;
label define UNCNET20  -9 "BLANK" ;
label define UNCNET31  -9 "BLANK" ;
label define UNCH5     -9 "BLANK" ;
label define UNCLED7   -9 "BLANK" ;
label define UNTRAN7   -9 "BLANK" ;
label define UNTRAN16  -9 "BLANK" ;
label define UNTRAN31  -9 "BLANK" ;
label define UNTRAN32  -9 "BLANK" ;
label define UNHIV7    -9 "BLANK" ;
label define UNHIV23   -9 "BLANK" ;
label define UNHOUS18  -9 "BLANK" ;
label define UNHM18    -9 "BLANK" ;
label define UNIASS31  -9 "BLANK" ;
label define UNIASS2   -9 "BLANK" ;
label define UNMDS7    -9 "BLANK" ;
label define UNMDS25   -9 "BLANK" ;
label define UNMDS31   -9 "BLANK" ;
label define UNMDS3    -9 "BLANK" ;
label define UNMDS24   -9 "BLANK" ;
label define UNMES15   -9 "BLANK" ;
label define UNMES16   -9 "BLANK" ;
label define UNMES31   -9 "BLANK" ;
label define UNMHGC31  -9 "BLANK" ;
label define UNMHGC11  -9 "BLANK" ;
label define UNMHIC11  -9 "BLANK" ;
label define UNMHIC8   -9 "BLANK" ;
label define UNPEV7    -9 "BLANK" ;
label define UNPSE13   -9 "BLANK" ;
label define UNPSE14   -9 "BLANK" ;
label define UNPSE16   -9 "BLANK" ;
label define UNPSE31   -9 "BLANK" ;
label define UNRMGT7   -9 "BLANK" ;
label define UNRMGT31  -9 "BLANK" ;
label define UNRMGT4   -9 "BLANK" ;
label define UNRMGT24  -9 "BLANK" ;
label define UNSTED7   -9 "BLANK" ;
label define UNSTED16  -9 "BLANK" ;
label define UNSTED31  -9 "BLANK" ;
label define UNSAGC11  -9 "BLANK" ;
label define UNSAGC31  -9 "BLANK" ;
label define UNSAIC11  -9 "BLANK" ;
label define UNSAI31   -9 "BLANK" ;
label define UCAFT7    -9.00 "BLANK" ;
label define UCSTAFT9  -9.00 "BLANK" ;
label define UCAFT10   -9.00 "BLANK" ;
label define UCAFT12   -9.00 "BLANK" ;
label define UCAFT3    -9.00 "BLANK" ;
label define UCCNET7   -9.00 "BLANK" ;
label define UCCNET9   -9.00 "BLANK" ;
label define UCCNET10  -9.00 "BLANK" ;
label define UCCNET16  -9.00 "BLANK" ;
label define UCCNET20  -9.00 "BLANK" ;
label define UCCNET31  -9.00 "BLANK" ;
label define UCCH5     -9.00 "BLANK" ;
label define UCCLED7   -9.00 "BLANK" ;
label define UCTRAN7   -9.00 "BLANK" ;
label define UCTRAN16  -9.00 "BLANK" ;
label define UCTRAN31  -9.00 "BLANK" ;
label define UCTRAN32  -9.00 "BLANK" ;
label define UCHIV7    -9.00 "BLANK" ;
label define UCHIV23   -9.0 "BLANK" ;
label define UCHOUS18  -9.00 "BLANK" ;
label define UCHM18    -9.00 "BLANK" ;
label define UCMHIC11  -9.00 "BLANK" ;
label define UCIASS31  -9.00 "BLANK" ;
label define UCIASS2   -9.00 "BLANK" ;
label define UCMDS7    -9.00 "BLANK" ;
label define UCMDS25   -9.00 "BLANK" ;
label define UCMDS31   -9.00 "BLANK" ;
label define UCMDS3    -9.00 "BLANK" ;
label define UCMDS24   -9.00 "BLANK" ;
label define UCMES15   -9.00 "BLANK" ;
label define UCMES16   -9.00 "BLANK" ;
label define UCMES31   -9.00 "BLANK" ;
label define UCMHGC11  -9.00 "BLANK" ;
label define UCPEV7    -9.00 "BLANK" ;
label define UCPSE13   -9.00 "BLANK" ;
label define UCPSE14   -9.00 "BLANK" ;
label define UCPSE16   -9.00 "BLANK" ;
label define UCPSE31   -9.00 "BLANK" ;
label define UCRMGT7   -9.00 "BLANK" ;
label define UCRMGT31  -9.00 "BLANK" ;
label define UCRMGT4   -9.00 "BLANK" ;
label define UCRMGT24  -9.00 "BLANK" ;
label define UCSTED7   -9.00 "BLANK" ;
label define UCSTED16  -9.00 "BLANK" ;
label define UCSTED31  -9.00 "BLANK" ;
label define UCSAGC11  -9.00 "BLANK" ;
label define UCSAGC31  -9.00 "BLANK" ;
label define UCSAIC11  -9.00 "BLANK" ;
label define UCSAIC31  -9 "BLANK" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace SDUTYPE = . if (SDUTYPE <= -1 )
replace NUMCLNT = . if (NUMCLNT <= -1 )
replace FYEND = . if (FYEND <= -1 )
replace TOTCOST = . if (TOTCOST <= -1 )
replace TOTAFT = . if (TOTAFT <= -1 )
replace TOTCNET = . if (TOTCNET <= -1 )
replace TOTCH = . if (TOTCH <= -1 )
replace TOTCLED = . if (TOTCLED <= -1 )
replace TOTTRAN = . if (TOTTRAN <= -1 )
replace TOTHIV = . if (TOTHIV <= -1 )
replace TOTHOUS = . if (TOTHOUS <= -1 )
replace TOTHM = . if (TOTHM <= -1 )
replace TOTIASS = . if (TOTIASS <= -1 )
replace TOTMDS = . if (TOTMDS <= -1 )
replace TOTMES = . if (TOTMES <= -1 )
replace TOTMHGC = . if (TOTMHGC <= -1 )
replace TOTMHIC = . if (TOTMHIC <= -1 )
replace TOTPEVL = . if (TOTPEVL <= -1 )
replace TOTPSE = . if (TOTPSE <= -1 )
replace TOTRMGT = . if (TOTRMGT <= -1 )
replace TOTSTED = . if (TOTSTED <= -1 )
replace TOTSAGC = . if (TOTSAGC <= -1 )
replace TOTSAIC = . if (TOTSAIC <= -1 )
replace CSTPRCL = . if (CSTPRCL <= -1.00 )
replace AVGAFT = . if (AVGAFT <= -1.00 )
replace AVGCNET = . if (AVGCNET <= -1.00 )
replace AVGCH = . if (AVGCH <= -1.00 )
replace AVGCLED = . if (AVGCLED <= -1.00 )
replace AVGTRAN = . if (AVGTRAN <= -1.00 )
replace AVGHIV = . if (AVGHIV <= -1.00 )
replace AVGHOUS = . if (AVGHOUS <= -1.00 )
replace AVGHM = . if (AVGHM <= -1.00 )
replace AVGIASS = . if (AVGIASS <= -1.00 )
replace AVGMDS = . if (AVGMDS <= -1.00 )
replace AVGMES = . if (AVGMES <= -1.00 )
replace AVGMHGC = . if (AVGMHGC <= -1.00 )
replace AVGMHIC = . if (AVGMHIC <= -1.00 )
replace AVGPEVL = . if (AVGPEVL <= -1.00 )
replace AVGPSE = . if (AVGPSE <= -1.00 )
replace AVGRMGT = . if (AVGRMGT <= -1.00 )
replace AVGSAGC = . if (AVGSAGC <= -1.00 )
replace AVGSAIC = . if (AVGSAIC <= -1.00 )
replace AVGSTED = . if (AVGSTED <= -1.00 )
replace UNAFT7 = . if (UNAFT7 <= -1 )
replace UNAFT9 = . if (UNAFT9 <= -1 )
replace UNAFT10 = . if (UNAFT10 <= -1 )
replace UNAFT12 = . if (UNAFT12 <= -1 )
replace UNAFT3 = . if (UNAFT3 <= -1 )
replace UNCNET7 = . if (UNCNET7 <= -1 )
replace UNCNET9 = . if (UNCNET9 <= -1 )
replace UNCNET10 = . if (UNCNET10 <= -1 )
replace UNCNET16 = . if (UNCNET16 <= -1 )
replace UNCNET20 = . if (UNCNET20 <= -1 )
replace UNCNET31 = . if (UNCNET31 <= -1 )
replace UNCH5 = . if (UNCH5 <= -1 )
replace UNCLED7 = . if (UNCLED7 <= -1 )
replace UNTRAN7 = . if (UNTRAN7 <= -1 )
replace UNTRAN16 = . if (UNTRAN16 <= -1 )
replace UNTRAN31 = . if (UNTRAN31 <= -1 )
replace UNTRAN32 = . if (UNTRAN32 <= -1 )
replace UNHIV7 = . if (UNHIV7 <= -1 )
replace UNHIV23 = . if (UNHIV23 <= -1 )
replace UNHOUS18 = . if (UNHOUS18 <= -1 )
replace UNHM18 = . if (UNHM18 <= -1 )
replace UNIASS31 = . if (UNIASS31 <= -1 )
replace UNIASS2 = . if (UNIASS2 <= -1 )
replace UNMDS7 = . if (UNMDS7 <= -1 )
replace UNMDS25 = . if (UNMDS25 <= -1 )
replace UNMDS31 = . if (UNMDS31 <= -1 )
replace UNMDS3 = . if (UNMDS3 <= -1 )
replace UNMDS24 = . if (UNMDS24 <= -1 )
replace UNMES15 = . if (UNMES15 <= -1 )
replace UNMES16 = . if (UNMES16 <= -1 )
replace UNMES31 = . if (UNMES31 <= -1 )
replace UNMHGC31 = . if (UNMHGC31 <= -1 )
replace UNMHGC11 = . if (UNMHGC11 <= -1 )
replace UNMHIC11 = . if (UNMHIC11 <= -1 )
replace UNMHIC8 = . if (UNMHIC8 <= -1 )
replace UNPEV7 = . if (UNPEV7 <= -1 )
replace UNPSE13 = . if (UNPSE13 <= -1 )
replace UNPSE14 = . if (UNPSE14 <= -1 )
replace UNPSE16 = . if (UNPSE16 <= -1 )
replace UNPSE31 = . if (UNPSE31 <= -1 )
replace UNRMGT7 = . if (UNRMGT7 <= -1 )
replace UNRMGT31 = . if (UNRMGT31 <= -1 )
replace UNRMGT4 = . if (UNRMGT4 <= -1 )
replace UNRMGT24 = . if (UNRMGT24 <= -1 )
replace UNSTED7 = . if (UNSTED7 <= -1 )
replace UNSTED16 = . if (UNSTED16 <= -1 )
replace UNSTED31 = . if (UNSTED31 <= -1 )
replace UNSAGC11 = . if (UNSAGC11 <= -1 )
replace UNSAGC31 = . if (UNSAGC31 <= -1 )
replace UNSAIC11 = . if (UNSAIC11 <= -1 )
replace UNSAI31 = . if (UNSAI31 <= -1 )
replace UCAFT7 = . if (UCAFT7 <= -1.00 )
replace UCSTAFT9 = . if (UCSTAFT9 <= -1.00 )
replace UCAFT10 = . if (UCAFT10 <= -1.00 )
replace UCAFT12 = . if (UCAFT12 <= -1.00 )
replace UCAFT3 = . if (UCAFT3 <= -1.00 )
replace UCCNET7 = . if (UCCNET7 <= -1.00 )
replace UCCNET9 = . if (UCCNET9 <= -1.00 )
replace UCCNET10 = . if (UCCNET10 <= -1.00 )
replace UCCNET16 = . if (UCCNET16 <= -1.00 )
replace UCCNET20 = . if (UCCNET20 <= -1.00 )
replace UCCNET31 = . if (UCCNET31 <= -1.00 )
replace UCCH5 = . if (UCCH5 <= -1.00 )
replace UCCLED7 = . if (UCCLED7 <= -1.00 )
replace UCTRAN7 = . if (UCTRAN7 <= -1.00 )
replace UCTRAN16 = . if (UCTRAN16 <= -1.00 )
replace UCTRAN31 = . if (UCTRAN31 <= -1.00 )
replace UCTRAN32 = . if (UCTRAN32 <= -1.00 )
replace UCHIV7 = . if (UCHIV7 <= -1.00 )
replace UCHIV23 = . if (UCHIV23 <= -1.0 )
replace UCHOUS18 = . if (UCHOUS18 <= -1.00 )
replace UCHM18 = . if (UCHM18 <= -1.00 )
replace UCMHIC11 = . if (UCMHIC11 <= -1.00 )
replace UCIASS31 = . if (UCIASS31 <= -1.00 )
replace UCIASS2 = . if (UCIASS2 <= -1.00 )
replace UCMDS7 = . if (UCMDS7 <= -1.00 )
replace UCMDS25 = . if (UCMDS25 <= -1.00 )
replace UCMDS31 = . if (UCMDS31 <= -1.00 )
replace UCMDS3 = . if (UCMDS3 <= -1.00 )
replace UCMDS24 = . if (UCMDS24 <= -1.00 )
replace UCMES15 = . if (UCMES15 <= -1.00 )
replace UCMES16 = . if (UCMES16 <= -1.00 )
replace UCMES31 = . if (UCMES31 <= -1.00 )
replace UCMHGC11 = . if (UCMHGC11 <= -1.00 )
replace UCPEV7 = . if (UCPEV7 <= -1.00 )
replace UCPSE13 = . if (UCPSE13 <= -1.00 )
replace UCPSE14 = . if (UCPSE14 <= -1.00 )
replace UCPSE16 = . if (UCPSE16 <= -1.00 )
replace UCPSE31 = . if (UCPSE31 <= -1.00 )
replace UCRMGT7 = . if (UCRMGT7 <= -1.00 )
replace UCRMGT31 = . if (UCRMGT31 <= -1.00 )
replace UCRMGT4 = . if (UCRMGT4 <= -1.00 )
replace UCRMGT24 = . if (UCRMGT24 <= -1.00 )
replace UCSTED7 = . if (UCSTED7 <= -1.00 )
replace UCSTED16 = . if (UCSTED16 <= -1.00 )
replace UCSTED31 = . if (UCSTED31 <= -1.00 )
replace UCSAGC11 = . if (UCSAGC11 <= -1.00 )
replace UCSAGC31 = . if (UCSAGC31 <= -1.00 )
replace UCSAIC11 = . if (UCSAIC11 <= -1.00 )
replace UCSAIC31 = . if (UCSAIC31 <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

